NAME
Zuzu::AST::Block - AST node representing a statement block
DESCRIPTION
AST container for a lexical block body that executes statements sequentially.
INHERITANCE
Inherits from Moo::Object.
ROLES
Consumes Zuzu::AST::Role::Node.
ATTRIBUTES
statements
Type: ArrayRef[ConsumerOf["Zuzu::AST::Role::Node"]].
Ordered child statements contained in the node.
METHODS
evaluate
Dispatches this AST node to the matching runtime evaluator.
SEE ALSO
Zuzu::AST::Role::Node.
Subclasses: none in this distribution.
COPYRIGHT AND LICENCE
Zuzu::AST::Block is copyright Toby Inkster.
It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.